@@ -7,7 +7,11 @@ class Peeker(object):
     def __init__(self, api):
         self._api = api
 
-    def peek(self, topology, stream):
+    def peek(self, topology, stream, count):
         query = 'SELECT RSTREAM * FROM {0} [RANGE 1 TUPLES];'.format(stream)
+        received = 0
         for data in self._api.query(topology, query):
-            return data
+            received += 1
+            yield data
+            if 0 < count and count <= received:
+                break
